@@ -10,8 +10,10 @@ config() {
   fi
   # Otherwise, we leave the .new copy for the admin to consider...
 }
-config etc/sensors.conf.new
-( cd usr/lib ; rm -rf libsensors.so.3 )
-( cd usr/lib ; ln -sf libsensors.so.3.1.7 libsensors.so.3 )
+config etc/sensors3.conf.new
+( cd usr/lib ; rm -rf libsensors.so.4 )
+( cd usr/lib ; ln -sf libsensors.so.4.3.2 libsensors.so.4 )
 ( cd usr/lib ; rm -rf libsensors.so )
-( cd usr/lib ; ln -sf libsensors.so.3 libsensors.so )
+( cd usr/lib ; ln -sf libsensors.so.4 libsensors.so )
+( cd usr/man/man5 ; rm -rf sensors3.conf.5.gz )
+( cd usr/man/man5 ; ln -sf sensors.conf.5.gz sensors3.conf.5.gz )
